@@ -56,19 +56,22 @@ use feature 'switch';
 use warnings;
 
 use vars qw($VERSION);
-$VERSION='6.07';
+$VERSION='6.10';
 
 ###########################################################################
 
-use vars qw($dmb $dmt $date $delta $recur $date2);
+use vars qw($dmb $dmt $date $delta $recur $date2 $dateUT);
 use Date::Manip::Date;
 
-$date  = new Date::Manip::Date;
-$date2 = $date->new_date();
-$delta = $date->new_delta();
-$recur = $date->new_recur();
-$dmb   = $date->base();
-$dmt   = $date->tz();
+$dateUT = new Date::Manip::Date;
+$dateUT->config("setdate","now,Etc/GMT");
+
+$date   = new Date::Manip::Date;
+$date2  = $date->new_date();
+$delta  = $date->new_delta();
+$recur  = $date->new_recur();
+$dmb    = $date->base();
+$dmt    = $date->tz();
 
 ########################################################################
 ########################################################################
@@ -790,13 +793,37 @@ sub Date_ConvTZ {
    my($str,$from,$to) = @_;
    $from = $dmb->_now("tz")  if (! $from);
    $to   = $dmb->_now("tz")  if (! $to);
-   $from = $dmt->zone($from);
-   return ''  if (! $from);
-   $to = $dmt->zone($to);
-   return ''  if (! $to);
-   my @d = @{ $dmb->split('date',$str) };
-   return ''  if (! @d);
-   my($err,$d) = $dmt->convert(\@d,$from,$to);
+
+   # Parse the date (ignoring timezone information):
+
+   my $err = $dateUT->parse($str);
+   return ''  if ($err);
+   my $d   = [ $dateUT->value() ];
+   return ''  if (! $d);
+
+   # Get the timezone for $from. First, we'll assume that
+   # the date matches exactly (so if the timezone is passed
+   # in as an abbreviation, we'll try to get the timezone
+   # that fits the date/abbrev combination). If we can't,
+   # we'll just assume that the timezone is more generic
+   # and try it without the date.
+
+   my $tmp;
+   $tmp = $dmt->zone($from,$d);
+   if (! $tmp) {
+      $tmp = $dmt->zone($from);
+      return ''  if (! $tmp);
+   }
+   $from = $tmp;
+
+   $tmp = $dmt->zone($to,$d);
+   if (! $tmp) {
+      $tmp = $dmt->zone($to);
+      return ''  if (! $tmp);
+   }
+   $to = $tmp;
+
+   ($err,$d) = $dmt->convert($d,$from,$to);
    return ''  if ($err);
    return $dmb->join('date',$d);
 }
@@ -820,6 +847,7 @@ sub Date_Cmp {
    my $err = $date->parse($str1);
    return undef  if ($err);
    $err = $date2->parse($str2);
+   return undef  if ($err);
    return $date->cmp($date2);
 }
 
