@@ -22,7 +22,7 @@ use feature 'switch';
 #use re 'debug';
 
 use vars qw($VERSION);
-$VERSION='6.07';
+$VERSION='6.10';
 
 ########################################################################
 # BASE METHODS
@@ -304,101 +304,113 @@ sub parse {
 }
 
 sub printf {
-   my($self,$in) = @_;
-   return ''  if ($$self{'err'});
-
-   my $out = '';
+   my($self,@in) = @_;
+   if ($$self{'err'}) {
+      warn "WARNING: [printf] Object must contain a valid delta\n";
+      return undef;
+   }
 
    my($y,$M,$w,$d,$h,$m,$s) = @{ $$self{'data'}{'delta'} };
 
-   while ($in) {
-      if ($in =~ s/^([^%]+)//) {
-         $out .= $1;
+   my @out;
+   foreach my $in (@in) {
+      my $out = '';
+      while ($in) {
+         if ($in =~ s/^([^%]+)//) {
+            $out .= $1;
 
-      } elsif ($in =~ s/^%%//) {
-         $out .= "%";
+         } elsif ($in =~ s/^%%//) {
+            $out .= "%";
 
-      } elsif ($in =~ s/^%
-                        (\+)?                   # sign
-                        ([<>0])?                # pad
-                        (\d+)?                  # width
-                        ([yMwdhms])             # field
-                        v                       # type
-                       //ox) {
-         my($sign,$pad,$width,$field) = ($1,$2,$3,$4);
-         $out .= $self->_printf_field($sign,$pad,$width,0,$field);
+         } elsif ($in =~ s/^%
+                           (\+)?                   # sign
+                           ([<>0])?                # pad
+                           (\d+)?                  # width
+                           ([yMwdhms])             # field
+                           v                       # type
+                          //ox) {
+            my($sign,$pad,$width,$field) = ($1,$2,$3,$4);
+            $out .= $self->_printf_field($sign,$pad,$width,0,$field);
 
-      } elsif ($in =~ s/^(%
-                        (\+)?                   # sign
-                        ([<>0])?                # pad
-                        (\d+)?                  # width
-                        (?:\.(\d+))?            # precision
-                        ([yMwdhms])             # field
-                        ([yMwdhms])             # field0
-                        ([yMwdhms])             # field1
-                       )//ox) {
-         my($match,$sign,$pad,$width,$precision,$field,$field0,$field1) =
-           ($1,$2,$3,$4,$5,$6,$7,$8);
+         } elsif ($in =~ s/^(%
+                              (\+)?                   # sign
+                              ([<>0])?                # pad
+                              (\d+)?                  # width
+                              (?:\.(\d+))?            # precision
+                              ([yMwdhms])             # field
+                              ([yMwdhms])             # field0
+                              ([yMwdhms])             # field1
+                           )//ox) {
+            my($match,$sign,$pad,$width,$precision,$field,$field0,$field1) =
+              ($1,$2,$3,$4,$5,$6,$7,$8);
 
-         # Get the list of fields we're expressing
+            # Get the list of fields we're expressing
 
-         my @field = qw(y M w d h m s);
-         while (@field  &&  $field[0] ne $field0) {
-            shift(@field);
-         }
-         while (@field  &&  $field[$#field] ne $field1) {
-            pop(@field);
-         }
+            my @field = qw(y M w d h m s);
+            while (@field  &&  $field[0] ne $field0) {
+               shift(@field);
+            }
+            while (@field  &&  $field[$#field] ne $field1) {
+               pop(@field);
+            }
+
+            if (! @field) {
+               $out .= $match;
+            } else {
+               $out .=
+                 $self->_printf_field($sign,$pad,$width,$precision,$field,@field);
+            }
+
+         } elsif ($in =~ s/^%
+                           (\+)?                   # sign
+                           ([<>])?                 # pad
+                           (\d+)?                  # width
+                           Dt
+                          //ox) {
+            my($sign,$pad,$width) = ($1,$2,$3);
+            $out .= $self->_printf_delta($sign,$pad,$width,'y','s');
+
+         } elsif ($in =~ s/^(%
+                              (\+)?                   # sign
+                              ([<>])?                 # pad
+                              (\d+)?                  # width
+                              D
+                              ([yMwdhms])             # field0
+                              ([yMwdhms])             # field1
+                           )//ox) {
+            my($match,$sign,$pad,$width,$field0,$field1) = ($1,$2,$3,$4,$5,$6);
+
+            # Get the list of fields we're expressing
+
+            my @field = qw(y M w d h m s);
+            while (@field  &&  $field[0] ne $field0) {
+               shift(@field);
+            }
+            while (@field  &&  $field[$#field] ne $field1) {
+               pop(@field);
+            }
+
+            if (! @field) {
+               $out .= $match;
+            } else {
+               $out .= $self->_printf_delta($sign,$pad,$width,$field[0],$field[$#field]);
+            }
 
-         if (! @field) {
-            $out .= $match;
          } else {
-            $out .=
-              $self->_printf_field($sign,$pad,$width,$precision,$field,@field);
+            $in =~ s/^(%[^%]*)//;
+            $out .= $1;
          }
-
-      } elsif ($in =~ s/^%
-                        (\+)?                   # sign
-                        ([<>])?                 # pad
-                        (\d+)?                  # width
-                        Dt
-                       //ox) {
-         my($sign,$pad,$width) = ($1,$2,$3);
-         $out .= $self->_printf_delta($sign,$pad,$width,'y','s');
-
-      } elsif ($in =~ s/^(%
-                        (\+)?                   # sign
-                        ([<>])?                 # pad
-                        (\d+)?                  # width
-                        D
-                        ([yMwdhms])             # field0
-                        ([yMwdhms])             # field1
-                       )//ox) {
-         my($match,$sign,$pad,$width,$field0,$field1) = ($1,$2,$3,$4,$5,$6);
-
-         # Get the list of fields we're expressing
-
-         my @field = qw(y M w d h m s);
-         while (@field  &&  $field[0] ne $field0) {
-            shift(@field);
-         }
-         while (@field  &&  $field[$#field] ne $field1) {
-            pop(@field);
-         }
-
-         if (! @field) {
-            $out .= $match;
-         } else {
-            $out .= $self->_printf_delta($sign,$pad,$width,$field[0],$field[$#field]);
-         }
-
-      } else {
-         $in =~ s/^(%[^%]*)//;
-         $out .= $1;
       }
+      push(@out,$out);
    }
 
-   return $out;
+   if (wantarray) {
+      return @out;
+   } elsif (@out == 1) {
+      return $out[0];
+   }
+
+   return ''
 }
 
 sub _printf_delta {
