@@ -24,7 +24,7 @@ require Date::Manip::Zones;
 use Date::Manip::Base;
 
 use vars qw($VERSION);
-$VERSION='6.07';
+$VERSION='6.10';
 
 ########################################################################
 # BASE METHODS
@@ -493,6 +493,8 @@ sub _get_curr_zone {
 
       foreach my $zone (@zone) {
          $zone = lc($zone);
+         # OpenUNIX puts a colon at the start
+         $zone =~ s/^://;
 
          # If we got a zone name/alias
          $currzone = $self->_zone($zone);
@@ -682,6 +684,12 @@ sub zone {
       }
 
       # $dstflag
+      #
+      # $dstflag is "dst' if
+      #    zone is passed in as an offset
+      #    date is passed in
+
+      $dstflag = "dst"  if ($offset  &&  $date  &&  ! $dstflag);
 
       my(@isdst);
       if      ($dstflag eq 'stdonly') {
